Calculate Career Success Index for Impact Analysis
Source:R/impact_metrics.R
calculate_career_success_index_for_impact.RdInternal helper function that calculates the unified career success index from component metrics calculated in the impact system.