Add Consolidation Information to tidygraph
Source:R/ggraph_transitions.R
dot-add_consolidation_info.RdInternal helper to add consolidation status to tidygraph edges.
R/ggraph_transitions.R
dot-add_consolidation_info.RdInternal helper to add consolidation status to tidygraph edges.