Skip to contents

Internal helper to add background highlights for different hierarchy levels. Creates colored background rectangles to visually separate different levels in tree and hierarchical layouts.

Usage

.add_level_backgrounds(colors, accessibility_mode)

Arguments

colors

Color palette to use for backgrounds

accessibility_mode

High contrast mode flag

Value

ggplot2 layer with background rectangles