Create Empty Heatmap Plot for Error Cases
Source:R/ggraph_transitions.R
dot-create_empty_heatmap_plot.RdInternal helper to create informative empty heatmap plots when data is insufficient.
R/ggraph_transitions.R
dot-create_empty_heatmap_plot.RdInternal helper to create informative empty heatmap plots when data is insufficient.