Skip to contents

This module provides comprehensive causal inference estimation functionality for impact evaluation studies including difference-in-differences, event study designs, synthetic control methods, and treatment effect aggregation.

Author

vecshift package