Skip to contents

This module provides comprehensive matching functionality for impact evaluation studies including propensity score matching, coarsened exact matching, and balance assessment with diagnostic tools.

Author

vecshift package