Loads the comuni and CPI shapefiles from the data/maps directory. These files contain polygons for Lombardy municipalities and CPI areas.
Loads the comuni and CPI shapefiles from the data/maps directory. These files contain polygons for Lombardy municipalities and CPI areas.