Helper: Get Survival Probability at Specific Time
Source:R/survival_analysis.R
get_survival_at_time.RdInternal helper function to extract survival probability at a given time from a survival table using step function logic.
R/survival_analysis.R
get_survival_at_time.RdInternal helper function to extract survival probability at a given time from a survival table using step function logic.