Impact Evaluation: Event Identification and Treatment Group Definition
Source:R/impact_evaluation.R
impact_evaluation.RdThis module provides comprehensive event identification functionality for impact evaluation studies using employment data. It supports flexible treatment conditions, multiple events per person, and robust event timing identification.