Skip to contents

Creates a visual preview of pattern and color combinations to help with selection for black and white visualizations.

Usage

preview_bw_patterns(
  pattern_type = "employment",
  show_patterns = TRUE,
  show_colors = FALSE
)

Arguments

pattern_type

Character. Type of patterns to preview

show_patterns

Logical. Whether to show pattern descriptions (default: TRUE)

show_colors

Logical. Whether to show hex color codes (default: FALSE)

Value

A ggplot2 object showing pattern and color combinations

Examples

if (FALSE) { # \dontrun{
# Preview employment patterns
preview_bw_patterns("employment")

# Preview contract patterns
preview_bw_patterns("contracts")
} # }